# Mineflex-py
Mineflex-py is an API written in Python

## Installation
``pip install mineflex-py``

## Docs
Will be added soon

## License
Mineflex-py is licensed under MIT, read `LICENSE` for more information
